package com.ynet.life.sujrb.file.parser;

import com.ynet.gene.core.Context;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.sujrb.file.BatchFileSummary;
import com.ynet.life.sujrb.file.BatchSkdBusnissSummary;
import com.ynet.life.sujrb.file.FileConstants;
import java.io.FileInputStream;
import java.io.IOException;
import java.text.DecimalFormat;
import java.text.SimpleDateFormat;
import java.util.HashMap;
import java.util.Map;
import java.util.StringTokenizer;
import java.util.regex.Pattern;
import org.apache.poi.hssf.usermodel.HSSFCell;
import org.apache.poi.hssf.usermodel.HSSFDateUtil;
import org.apache.poi.hssf.usermodel.HSSFRow;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.poifs.filesystem.OfficeXmlFileException;
import org.apache.poi.poifs.filesystem.POIFSFileSystem;

/* loaded from: com_ynet_life_sujrb_file_parser.jar:com/ynet/life/sujrb/file/parser/BatchSKDDataDetailImport.class */
public class BatchSKDDataDetailImport implements BatchFileParserInterface {
    private String formatter;
    private Context context;

    public BatchSKDDataDetailImport() {
    }

    public BatchSKDDataDetailImport(String formatter) {
        this.formatter = formatter;
    }

    public Context getContext() {
        return this.context;
    }

    public void setContext(Context context) {
        this.context = context;
    }

    @Override // com.ynet.life.sujrb.file.parser.BatchFileParserInterface
    public BatchFileSummary parseFromFile(String filePathName) throws TranFailException {
        try {
            POIFSFileSystem file = new POIFSFileSystem(new FileInputStream(filePathName));
            HSSFWorkbook workBook = new HSSFWorkbook(file);
            BatchSkdBusnissSummary result = new BatchSkdBusnissSummary();
            try {
                HSSFSheet sheet = workBook.getSheetAt(0);
                HSSFRow summaryRow = sheet.getRow(0);
                int rowIndex = 1;
                HSSFRow recordRowTemp = sheet.getRow(1);
                if (getCellContent(recordRowTemp, 0, true).trim().equals("结束")) {
                    throw new TranFailException("excelError", "文件解析失败");
                }
                if (summaryRow.getPhysicalNumberOfCells() != 13) {
                    throw new TranFailException("excelError", "模板错误");
                }
                while (true) {
                    int i = rowIndex;
                    rowIndex++;
                    HSSFRow recordRow = sheet.getRow(i);
                    if (!getCellContent(recordRow, 0, true).trim().equals("结束")) {
                        if (this.formatter == null) {
                            result.addRecord(getRecordMap(recordRow));
                        } else {
                            result.addRecord(getRecordMap(recordRow, this.formatter));
                        }
                    } else {
                        return result;
                    }
                }
            } catch (Exception ex) {
                Trace.logError("LifeFile", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏", ex);
                throw new TranFailException("EBCB0504", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏", false);
            }
        } catch (OfficeXmlFileException e) {
            Trace.logError("LifeFile", "Excel版本过高", e);
            throw new TranFailException("excelError", "Excel版本过高");
        } catch (IOException ex2) {
            Trace.logError("LifeFile", "文件读取失败", ex2);
            throw new TranFailException("excelError", "文件读取失败");
        }
    }

    private Map getRecordMap(HSSFRow recordRow) throws TranFailException {
        Map result = new HashMap();
        String skdBsnsCorName = getCellContent(recordRow, 0, true);
        String skdBsnsOrgcode = getCellContent(recordRow, 1, true);
        String skdContactName = getCellContent(recordRow, 2, true);
        String skdLoanProcess = getCellContent(recordRow, 3, true);
        String skdType = getCellContent(recordRow, 4, false);
        String skdLoanBranch = getCellContent(recordRow, 5, false);
        String skdApplyAmt = getCellContent(recordRow, 6, false);
        String skdAproBaAmt = getCellContent(recordRow, 7, false);
        String skdLoanAmt = getCellContent(recordRow, 8, false);
        String skdLoanDate = getCellContent(recordRow, 9, false);
        String skdRepayDate = getCellContent(recordRow, 10, false);
        String skdCenterBaDate = getCellContent(recordRow, 11, false);
        String skdLoanNo = getCellContent(recordRow, 12, false);
        SimpleDateFormat dateFormat = new SimpleDateFormat("yyyyMMdd");
        String remark = "";
        if ("".equals(skdBsnsCorName) || skdBsnsCorName == null) {
            remark = String.valueOf(remark) + "企业名称为空";
        } else {
            skdBsnsCorName = skdBsnsCorName.replace("(", "（").replace(")", "）");
        }
        if ("".equals(skdContactName) || skdContactName == null) {
            remark = String.valueOf(remark) + " 二级机构联系人姓名为空";
        }
        if ("".equals(skdLoanProcess) || skdLoanProcess == null) {
            remark = String.valueOf(remark) + " 贷款进程为空";
        } else if (!"企业已还款".equals(skdLoanProcess) && !"省中心备案通过".equals(skdLoanProcess) && !"已放款".equals(skdLoanProcess)) {
            remark = String.valueOf(remark) + " 贷款进程错误";
        }
        if ("".equals(skdType) || skdType == null) {
            remark = String.valueOf(remark) + " 苏科贷类型为空";
        }
        if ("".equals(skdLoanBranch) || skdLoanBranch == null) {
            remark = String.valueOf(remark) + " 贷款银行-总行为空";
        }
        if ("".equals(skdApplyAmt) || skdApplyAmt == null) {
            remark = String.valueOf(remark) + " 申请苏科贷金额(万元)为空";
        } else if (!Pattern.compile("^[1-9]{1}\\d*$").matcher(skdApplyAmt).matches()) {
            remark = String.valueOf(remark) + " 申请苏科贷金额(万元)不符合规则";
        } else {
            skdApplyAmt = String.valueOf(Long.parseLong(skdApplyAmt) * 10000);
        }
        if ("".equals(skdAproBaAmt) || skdAproBaAmt == null) {
            remark = String.valueOf(remark) + " 省同意备案金额(万元)为空";
        } else if (!Pattern.compile("^[1-9]{1}\\d*$").matcher(skdAproBaAmt).matches()) {
            remark = String.valueOf(remark) + " 省同意备案金额(万元)不符合规则";
        } else {
            skdAproBaAmt = String.valueOf(Long.parseLong(skdAproBaAmt) * 10000);
        }
        if ("已放款".equals(skdLoanProcess) || "企业已还款".equals(skdLoanProcess)) {
            if ("".equals(skdLoanAmt) || skdLoanAmt == null) {
                remark = String.valueOf(remark) + " 实际放款金额(万)为空";
            } else if (!Pattern.compile("^[1-9]{1}\\d*$").matcher(skdLoanAmt).matches()) {
                remark = String.valueOf(remark) + " 实际放款金额(万)不符合规则";
            } else {
                skdLoanAmt = String.valueOf(Long.parseLong(skdLoanAmt) * 10000);
            }
            if ("".equals(skdLoanDate) || skdLoanDate == null) {
                remark = String.valueOf(remark) + " 贷款发放日期为空";
                skdLoanDate = "";
            } else {
                try {
                    dateFormat.parse(skdLoanDate);
                } catch (Exception unused) {
                    remark = String.valueOf(remark) + " 贷款发放日期不符合规则";
                }
            }
        }
        if ("企业已还款".equals(skdLoanProcess)) {
            if ("".equals(skdRepayDate) || skdRepayDate == null) {
                remark = String.valueOf(remark) + " 贷款偿还日期为空";
                skdRepayDate = "";
            } else {
                try {
                    dateFormat.parse(skdRepayDate);
                } catch (Exception unused2) {
                    remark = String.valueOf(remark) + " 贷款偿还日期不符合规则";
                }
            }
        }
        if ("".equals(skdCenterBaDate) || skdCenterBaDate == null) {
            remark = String.valueOf(remark) + " 省中心同意备案日期为空";
            skdCenterBaDate = "";
        } else {
            try {
                dateFormat.parse(skdCenterBaDate);
            } catch (Exception unused3) {
                remark = String.valueOf(remark) + " 省中心同意备案日期不符合规则";
            }
        }
        result.put("skdBsnsCorName", skdBsnsCorName);
        result.put("skdBsnsOrgcode", skdBsnsOrgcode);
        result.put("skdContactName", skdContactName);
        result.put("skdLoanProcess", skdLoanProcess);
        result.put("skdType", skdType);
        result.put("skdLoanBranch", skdLoanBranch);
        result.put("skdApplyAmt", skdApplyAmt);
        result.put("skdAproBaAmt", skdAproBaAmt);
        result.put("skdLoanAmt", skdLoanAmt);
        result.put("skdLoanDate", "" == skdLoanDate ? "" : skdLoanDate.replaceAll("[[\\s-:punct:]]", ""));
        result.put("skdRepayDate", "" == skdRepayDate ? "" : skdRepayDate.replaceAll("[[\\s-:punct:]]", ""));
        result.put("skdCenterBaDate", "" == skdCenterBaDate ? "" : skdCenterBaDate.replaceAll("[[\\s-:punct:]]", ""));
        result.put("skdLoanNo", skdLoanNo);
        result.put("skdRemark", remark);
        return result;
    }

    private Map getRecordMap(HSSFRow recordRow, String formatter) throws TranFailException {
        Map result = new HashMap();
        StringTokenizer formatters = new StringTokenizer(formatter, "||");
        int i = 0;
        while (formatters.hasMoreTokens()) {
            String name = (String) formatters.nextElement();
            result.put(name, getCellContent(recordRow, i, true));
            i++;
        }
        return result;
    }

    /* JADX WARN: Can't fix incorrect switch cases order, some code will duplicate */
    private String getCellContent(HSSFRow row, int index, boolean toInt) throws TranFailException {
        String result = null;
        try {
            HSSFCell cell = row.getCell(index);
            if (cell != null) {
                switch (cell.getCellType()) {
                    case 0:
                        String format = "######.##";
                        if (toInt) {
                            format = "#######";
                        }
                        if (HSSFDateUtil.isCellDateFormatted(cell)) {
                            result = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss").format(HSSFDateUtil.getJavaDate(cell.getNumericCellValue()));
                            break;
                        } else {
                            result = new DecimalFormat(format).format(cell.getNumericCellValue());
                            break;
                        }
                    case 1:
                        result = cell.getRichStringCellValue().getString();
                        break;
                }
            }
            return result == null ? "" : result.trim();
        } catch (Exception ex) {
            Trace.logError("LifeFile", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏", ex);
            throw FileConstants.EXCEPTION_PARSE_FAIL;
        }
    }

    @Override // com.ynet.life.sujrb.file.parser.BatchFileParserInterface
    public void writeToFile(BatchFileSummary salary, String filePathName, String encoding) throws TranFailException {
    }
}
